@@ -65,10 +65,10 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    private final class GetParameterMapPrivilegedAction implements PrivilegedAction<Map<String, String[]>> {
+    private final class GetParameterMapPrivilegedAction implements PrivilegedAction<Map<String,String[]>> {
 
         @Override
-        public Map<String, String[]> run() {
+        public Map<String,String[]> run() {
             return request.getParameterMap();
         }
     }
@@ -347,7 +347,7 @@ public class RequestFacade implements HttpServletRequest {
 
 
     @Override
-    public Map<String, String[]> getParameterMap() {
+    public Map<String,String[]> getParameterMap() {
         checkFacade();
 
         if (Globals.IS_SECURITY_ENABLED) {
@@ -646,7 +646,6 @@ public class RequestFacade implements HttpServletRequest {
 
     @Override
     public HttpSession getSession() {
-        checkFacade();
         return getSession(true);
     }
 
@@ -812,7 +811,7 @@ public class RequestFacade implements HttpServletRequest {
 
     @Override
     public <T extends HttpUpgradeHandler> T upgrade(Class<T> httpUpgradeHandlerClass)
-            throws java.io.IOException, ServletException {
+            throws IOException, ServletException {
         checkFacade();
         return request.upgrade(httpUpgradeHandlerClass);
     }
