@@ -276,6 +276,8 @@ public abstract class AbstractEndpoint<S,U> {
                 isSSLEnabled()) {
             try {
                 createSSLContext(sslHostConfig);
+            } catch (IllegalArgumentException e) {
+                throw e;
             } catch (Exception e) {
                 throw new IllegalArgumentException(e);
             }
