@@ -43,6 +43,8 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 
+import javax.sql.XAConnection;
+
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 
@@ -364,8 +366,8 @@ public class ConnectionPool {
         //cache the constructor
         if (proxyClassConstructor == null ) {
             Class<?> proxyClass = xa ?
-                Proxy.getProxyClass(ConnectionPool.class.getClassLoader(), new Class[] {java.sql.Connection.class,javax.sql.PooledConnection.class, javax.sql.XAConnection.class}) :
-                Proxy.getProxyClass(ConnectionPool.class.getClassLoader(), new Class[] {java.sql.Connection.class,javax.sql.PooledConnection.class});
+                Proxy.getProxyClass(ConnectionPool.class.getClassLoader(), new Class[] {Connection.class, PooledConnection.class, XAConnection.class}) :
+                Proxy.getProxyClass(ConnectionPool.class.getClassLoader(), new Class[] {Connection.class, PooledConnection.class});
             proxyClassConstructor = proxyClass.getConstructor(new Class[] { InvocationHandler.class });
         }
         return proxyClassConstructor;
@@ -1044,7 +1046,7 @@ public class ConnectionPool {
                     long time = con.getTimestamp();
                     long now = System.currentTimeMillis();
                     if (shouldAbandon() && (now - time) > con.getAbandonTimeout()) {
-                        busy.remove(con);
+                        locked.remove();
                         abandon(con);
                         setToNull = true;
                     } else if (sto > 0 && (now - time) > (sto * 1000L)) {
@@ -1095,7 +1097,7 @@ public class ConnectionPool {
                     if (shouldReleaseIdle(now, con, time)) {
                         releasedIdleCount.incrementAndGet();
                         release(con);
-                        idle.remove(con);
+                        unlocked.remove();
                         setToNull = true;
                     } else {
                         //do nothing
@@ -1143,7 +1145,7 @@ public class ConnectionPool {
                     }
                     if (!con.validate(PooledConnection.VALIDATE_IDLE)) {
                         releasedIdleCount.incrementAndGet();
-                        idle.remove(con);
+                        unlocked.remove();
                         release(con);
                     }
                 } finally {
@@ -1398,7 +1400,9 @@ public class ConnectionPool {
                 if (configured.compareAndSet(false, true)) {
                     try {
                         pc = borrowConnection(System.currentTimeMillis(),pc, null, null);
-                        result = ConnectionPool.this.setupConnection(pc);
+                        if (pc != null) {
+                            result = ConnectionPool.this.setupConnection(pc);
+                        }
                     } catch (SQLException x) {
                         cause = x;
                     } finally {
@@ -1440,11 +1444,13 @@ public class ConnectionPool {
         public void run() {
             try {
                 Connection con = get(); //complete this future
-                con.close(); //return to the pool
+                if (con != null) {
+                    con.close(); //return to the pool
+                }
             }catch (ExecutionException ex) {
                 //we can ignore this
             }catch (Exception x) {
-                ConnectionPool.log.error("Unable to cancel ConnectionFuture.",x);
+                log.error("Unable to cancel ConnectionFuture.",x);
             }
         }
 
@@ -1496,7 +1502,8 @@ public class ConnectionPool {
         }
     }
 
-    public static Set<TimerTask> getPoolCleaners() {
+    // Testing use only
+    public static synchronized Set<TimerTask> getPoolCleaners() {
         return Collections.<TimerTask>unmodifiableSet(cleaners);
     }
 
@@ -1504,7 +1511,8 @@ public class ConnectionPool {
         return poolVersion.get();
     }
 
-    public static Timer getPoolTimer() {
+    // Testing use only
+    public static synchronized Timer getPoolTimer() {
         return poolCleanTimer;
     }
 
